@@ -205,6 +205,49 @@ setClass(
     list(experiments=experiments, sampleMap=sampleMap, colData=colData)
 }
 
+.checkFixSampleMap <- function(samplemap) {
+    samplemap <- as(samplemap, "DataFrame")
+    smapnames <- c("assay", "primary", "colname")
+    if (!all(smapnames %in% colnames(samplemap)))
+        stop("'sampleMap' does not have required columns")
+
+    if (!identical(colnames(samplemap), smapnames))
+        samplemap <- samplemap[, smapnames]
+
+    .smapColumnCoerce(samplemap)
+}
+
+.smapColumnCoerce <- function(samplemap) {
+    isfuns <- list(is.factor, is.character, is.character)
+    colsOK <- mapply(
+        FUN = function(fun, X) { fun(X) },  fun = isfuns, X = samplemap
+    )
+    if (all(colsOK))
+        return(samplemap)
+    asfuns <- list(
+        as.factor = as.factor,
+        as.character = as.character,
+        as.character = as.character
+    )
+    samplemap[] <- Map(
+        function(cName, isFun, coerceFun, funname) {
+            smapCol <- samplemap[[cName]]
+            if (!isFun(smapCol))
+                warning(
+                    "sampleMap[['", cName, "']] coerced with ", funname, "()",
+                    call. = FALSE
+                )
+            samplemap[[cName]] <- coerceFun(samplemap[[cName]])
+        },
+        cName = names(samplemap),
+        isFun = isfuns,
+        coerceFun = asfuns,
+        funname = names(asfuns)
+    )
+
+    samplemap
+}
+
 #' Construct an integrative representation of multi-omic data with
 #' \code{MultiAssayExperiment}
 #'
@@ -291,24 +334,9 @@ MultiAssayExperiment <-
             )
     }
 
+    sampleMap <- .checkFixSampleMap(sampleMap)
+
     colData <- as(colData, "DataFrame")
-    sampleMap <- as(sampleMap, "DataFrame")
-
-    if (!all(c("assay", "primary", "colname") %in% colnames(sampleMap)))
-        stop("'sampleMap' does not have required columns")
-    if (!is.factor(sampleMap[["assay"]]))
-        sampleMap[["assay"]] <- as.factor(sampleMap[["assay"]])
-    if (!is.character(sampleMap[["primary"]])) {
-        warning("sampleMap[['primary']] coerced to character()")
-        sampleMap[["primary"]] <- as.character(sampleMap[["primary"]])
-    }
-    if (!is.character(sampleMap[["colname"]])) {
-        warning("sampleMap[['colname']] coerced to character()")
-        sampleMap[["colname"]] <- as.character(sampleMap[["colname"]])
-    }
-
-    if ((isEmpty(sampleMap) && !missing(sampleMap)) & !isEmpty(experiments))
-        warning("An empty 'sampleMap' may cause unexpected behavior")
 
     bliss <- .harmonize(experiments, colData, sampleMap)
 
@@ -329,7 +357,8 @@ MultiAssayExperiment <-
 .checkExperimentList <- function(object) {
     errors <- character()
     assays <- levels(sampleMap(object)[["assay"]])
-    if (length(experiments(object)) != length(assays)) {
+    if (!is.null(assays) &&
+        !identical(length(experiments(object)), length(assays))) {
         msg <- paste0("ExperimentList must be the same length as",
                       " the sampleMap assay column")
         errors <- c(errors, msg)
@@ -337,12 +366,29 @@ MultiAssayExperiment <-
 
 ## 1.ii. Element names of the ExperimentList should be found in the
 ## sampleMap "assay" column.
-    if (!all(names(experiments(object)) %in% assays)) {
+    if (!is.null(assays) && !all(names(experiments(object)) %in% assays)) {
         msg <- paste0("All ExperimentList names were not found in",
                       " the sampleMap assay column")
         errors <- c(errors, msg)
     }
-    if (length(errors)) NULL else errors
+
+## 1.iii. ExperimentList cannot have any non-empty elements when the sampleMap
+## is empty.
+    if (isEmpty(sampleMap(object)) && !isEmpty(experiments(object))) {
+        msg <- paste0(
+            "All non-empty elements in the ExperimentList must have",
+            " names in the sampleMap assay column"
+        )
+        errors <- c(errors, msg)
+    }
+
+    if (!length(errors)) NULL else errors
+}
+
+.id_sort_uniq <- function(x, y) {
+    identical(
+        sort(unique(x)), sort(unique(y))
+    )
 }
 
 ## 1.iii. For each ExperimentList element, colnames must be found in the
@@ -351,16 +397,15 @@ MultiAssayExperiment <-
     sampMap <- sampleMap(object)
     assayCols <- mapToList(sampMap[, c("assay", "colname")])
     colNams <- Filter(function(x) !isEmpty(x), colnames(object))
+    msg <- NULL
     if (length(colNams)) {
         logicResult <- mapply(function(x, y) {
-            identical(sort(x), sort(y))
-        }, x = colNams, y = assayCols)
-    if (all(logicResult))
-        NULL
-    else
-        "not all samples in the ExperimentList are found in the sampleMap"
+            .id_sort_uniq(x = x, y = y)
+        }, x = colNams, y = assayCols[names(colNams)])
+        if (!all(logicResult))
+            msg <- "not all ExperimentList samples are found in the sampleMap"
     }
-    NULL
+    msg
 }
 
 ## COLDATA
@@ -425,7 +470,7 @@ setMethod("show", "MultiAssayExperiment", function(object) {
     o_class <- class(object)
     o_len <- length(object)
     o_names <- names(object)
-    if (length(o_names) == 0L) {
+    if (!length(o_names)) {
         o_names <- "none"
     }
     c_elist <- class(experiments(object))
@@ -435,7 +480,7 @@ setMethod("show", "MultiAssayExperiment", function(object) {
         "object of", o_len, "listed\n",
         ifelse(o_len == 1L, "experiment", "experiments"),
         "with",
-        ifelse(all(o_names == "none"), "no user-defined names",
+        ifelse(identical(o_names, "none"), "no user-defined names",
                ifelse(length(o_names) == 1L, "a user-defined name",
                       "user-defined names")),
         ifelse(length(o_len) == 0L, "or", "and"),
@@ -473,6 +518,7 @@ setMethod("show", "MultiAssayExperiment", function(object) {
 #'    \item experiments: Access the \link{ExperimentList} slot
 #'    \item `[[`: Access the \link{ExperimentList} slot
 #'    \item `$`: Access a column in \code{colData}
+#'    \item `drops`: Get a vector of dropped \link{ExperimentList} names
 #' }
 #'
 #' @section Setters:
@@ -488,6 +534,8 @@ setMethod("show", "MultiAssayExperiment", function(object) {
 #'     \item `[[<-`: Equivalent to the \code{experiments<-} setter method for
 #'     convenience
 #'     \item `$<-`: A vector to replace the indicated column in \code{colData}
+#'     \item `drops<-`: Trace \link{ExperimentList} names that have been
+#'     removed
 #' }
 #'
 #' @param object,x A \code{MultiAssayExperiment} object
@@ -504,7 +552,7 @@ setMethod("show", "MultiAssayExperiment", function(object) {
 #'
 #' @example inst/scripts/MultiAssayExperiment-methods-Ex.R
 #'
-#' @aliases experiments sampleMap experiments<- sampleMap<-
+#' @aliases experiments sampleMap experiments<- sampleMap<- drops drops<-
 NULL
 
 ### - - - - - - - - - - - - - - - - - - - - - - -
@@ -534,11 +582,14 @@ setMethod("colData", "MultiAssayExperiment", function(x, ...) {
     getElement(x, "colData")
 })
 
-#' @exportMethod metadata
+#' @export
+setGeneric("drops", function(x) standardGeneric("drops"))
+
+#' @exportMethod drops
 #' @rdname MultiAssayExperiment-methods
-setMethod("metadata", "MultiAssayExperiment", function(x)
-    c(getElement(x, "metadata"), drops = getElement(x, "drops"))
-)
+setMethod("drops", "MultiAssayExperiment", function(x) {
+    getElement(x, "drops")
+})
 
 ### - - - - - - - - - - - - - - - - - - - - - - - -
 ### Getters
@@ -597,6 +648,8 @@ setReplaceMethod("sampleMap", c("MultiAssayExperiment", "ANY"),
 setGeneric("experiments<-", function(object, value)
     standardGeneric("experiments<-"))
 
+#' @export
+#' @rdname MultiAssayExperiment-methods
 setGeneric("drops<-", function(x, ..., value) standardGeneric("drops<-"))
 
 #' @exportMethod experiments<-
@@ -604,9 +657,10 @@ setGeneric("drops<-", function(x, ..., value) standardGeneric("drops<-"))
 setReplaceMethod("experiments", c("MultiAssayExperiment", "ExperimentList"),
     function(object, value) {
         if (!any(names(object) %in% names(value)) && !isEmpty(object)) {
+            if (isEmpty(drops(object)))
+                warning("'experiments' dropped; see 'drops()'", call. = FALSE)
             drops(object) <-
                 list(experiments = setdiff(names(object), names(value)))
-            warning("'experiments' dropped; see 'metadata'", call. = FALSE)
         }
         o_cnames <- colnames(object)
         v_cnames <- colnames(value)
@@ -693,20 +747,8 @@ setReplaceMethod("colData", c("MultiAssayExperiment", "ANY"),
     }
 )
 
-.rearrangeMap <- function(sampMap) {
-    return(DataFrame(assay = factor(sampMap[["assayname"]]),
-                     primary = sampMap[["primary"]],
-                     colname = sampMap[["assay"]]))
-}
-
-#' @exportMethod metadata<-
+#' @exportMethod drops<-
 #' @rdname MultiAssayExperiment-methods
-setReplaceMethod("metadata", c("MultiAssayExperiment", "ANY"),
-    function(x, ..., value) {
-        slot(x, "metadata") <- value
-        return(x)
-})
-
 setReplaceMethod("drops", c("MultiAssayExperiment", "ANY"),
     function(x, ..., value) {
         anydrops <- getElement(x, "drops")[["experiments"]]
@@ -806,7 +848,7 @@ setMethod("updateObject", "MultiAssayExperiment",
         oldEL <- try(object@ExperimentList, silent = TRUE)
         if (is(oldEL, "try-error")) {
             explist <- ExperimentList(object@Elist@listData)
-            samplemap <- .rearrangeMap(object@sampleMap)
+            samplemap <- .checkFixSampleMap(object@sampleMap)
         } else {
             explist <- experiments(object)
             samplemap <- sampleMap(object)
