@@ -824,11 +824,10 @@ setMethod("splitAssays", "MultiAssayExperiment",
         })
         sublist <- unlist(sublist, recursive = FALSE)
         names(sublist) <- gsub("\\.", "_", names(sublist))
+        names(x) <- names(sublist)
 
-        BiocBaseUtils::setSlots(
-            object = x,
-            ExperimentList = ExperimentList(sublist)
-        )
+        experiments(x) <- ExperimentList(sublist)
+        x
     }
 )
 
@@ -839,14 +838,15 @@ setMethod("splitAssays", "MultiAssayExperiment",
 #' @examples
 #'
 #' patts <- list(
-#'     normals = "TCGA-OR-[A-Z0-9]{4}-11",
-#'     tumors = "TCGA-OR-[A-Z0-9]{4}-01"
+#'     normals = "TCGA-[A-Z0-9]{2}-[A-Z0-9]{4}-11",
+#'     tumors = "TCGA-[A-Z0-9]{2}-[A-Z0-9]{4}-01"
 #' )
 #'
 #' data("miniACC")
 #'
 #' hits <- makeHitList(miniACC, patts)
 #'
+#' ## only turmors present
 #' splitAssays(miniACC, hits)
 #'
 #' @export
