@@ -15,7 +15,7 @@ NULL
     if (length(matches) && all(is.na(matches)))
         stop("No way to map colData to ExperimentList")
     else if (!length(matches) && !isEmpty(experiments))
-        warning("colData rownames and ExperimentList colnames are empty")
+        stop("colData rownames and ExperimentList colnames are empty")
     primary <- rownames(colData)[matches]
     autoMap <- S4Vectors::DataFrame(
         assay=assay, primary=primary, colname=colname)
@@ -107,6 +107,21 @@ setMethod("$", "MultiAssayExperiment", function(x, name) {
     colData(x)[[name]]
 })
 
+#' @importFrom S4Vectors metadata
+#' @rdname MultiAssayExperiment-methods
+#' @exportMethod metadata
+setMethod("metadata", "MultiAssayExperiment", function(x, ...) {
+    callNextMethod()
+})
+
+#' @importFrom S4Vectors metadata<-
+#' @rdname MultiAssayExperiment-methods
+#' @exportMethod metadata<-
+setReplaceMethod("metadata", c("MultiAssayExperiment", "ANY"),
+    function(x, ..., value) {
+        callNextMethod()
+    }
+)
 
 .splitArgs <- function(args) {
     assayArgNames <- c("mcolname", "background", "type",
@@ -170,6 +185,14 @@ setMethod("c", "MultiAssayExperiment",
     if (!length(args))
         stop("Provide experiments or a 'MultiAssayExperiment' to concatenate")
 
+    if (
+        !is.null(sampleMap) && !is.list(sampleMap) &&
+        !is(sampleMap, "DataFrame")
+    )
+        stop(
+            "'sampleMap' must be a 'DataFrame', 'data.frame', 'list' or 'NULL'"
+        )
+
     if (identical(length(args), 1L)) {
         input <- args[[1L]]
         if (is(input, "MultiAssayExperiment"))
@@ -193,21 +216,17 @@ setMethod("c", "MultiAssayExperiment",
             sampleMap <- mapply(function(x, y) {
                 x[["colname"]] <- colnames(y)
                 x
-            }, addMaps, exps)
-        } else if (is.null(sampleMap)) {
+            }, x = addMaps, y = exps)
+        } else if (is.null(sampleMap) || isEmpty(sampleMap)) {
             sampleMap <- lapply(colnames(exps), .sampleMapFromExisting,
                 colData = cdata, sampleMap = xmap)
-            sampleMap <- listToMap(sampleMap)
         }
-        if (is(sampleMap, "DataFrame") || is.data.frame(sampleMap))
-            sampleMap <- mapToList(sampleMap)
-        else if (!is.list(sampleMap))
-            stop("'sampleMap' must be a 'DataFrame', 'data.frame', or 'list'")
-        newListMap <- c(mapToList(xmap),
-            IRanges::SplitDataFrameList(sampleMap))
+        if (!is(sampleMap, "DataFrame"))
+            sampleMap <- listToMap(sampleMap)
+        newListMap <- rbind(xmap, sampleMap)
         x <- BiocBaseUtils::setSlots(x,
             ExperimentList = c(experiments(x), exps),
-            sampleMap = listToMap(newListMap)
+            sampleMap = newListMap
         )
     }
     return(x)
