@@ -20,7 +20,7 @@
             explist@listData[[i]] <- exps[[i]]
         }
     }
-    x <- BiocGenerics:::replaceSlots(x, ExperimentList = explist, check = FALSE)
+    x <- BiocBaseUtils::setSlots(x, ExperimentList = explist, check = FALSE)
     if (verbose)
         message("Serialize ", class(x), " object to ",
                 ifelse(file.exists(rds_path), "existing ", ""),
@@ -62,7 +62,7 @@
     .write_h5_dimnames(assaylist, h5_path)
     ## avoid errors with arrays (withDimnames=FALSE)
     assays(explist, withDimnames = FALSE) <- exps
-    x <- BiocGenerics:::replaceSlots(
+    x <- BiocBaseUtils::setSlots(
         x, ExperimentList = explist, check = FALSE
     )
     .serialize_HDF5MultiAssayExperiment(x, rds_path, verbose)
@@ -74,45 +74,47 @@
 #' @title Save a MultiAssayExperiment class object to HDF5 and Rds files
 #'
 #' @description
-#'     This function takes a `MultiAssayExperiment` object and uses the `assays`
-#'     functionality to obtain data matrices out of the experiments. These are
-#'     then saved into the `.h5` file format. This function relies heavily on
-#'     the `HDF5Array` package whose installation is required before use.
-#'     `saveHDF5MultiAssayExpeirment` preserves the classes contained in the
-#'     \linkS4class{ExperimentList} with the exception of `matrix` which is
-#'     converted to `HDF5Matrix`. Internal `SummarizedExperiment` assays are
-#'     converted to HDF5-backed assays as in
-#'     `HDF5Array::saveHDF5SummarizedExperiment`. `SummarizedExperiment`
-#'     objects with multiple `i`-th assays will have the first assay take
-#'     precedence and others assays will be dropped with a warning.
-#'     If the first assay in a `SummarizedExperiment` contains an array,
-#'     the array is preserved in the process of saving and loading the
-#'     HDF5-backed `MultiAssayExperiment`.
+#'   This function takes a `MultiAssayExperiment` object and uses the `assays`
+#'   functionality to obtain data matrices out of the experiments. These are
+#'   then saved into the `.h5` file format. This function relies heavily on
+#'   the `HDF5Array` package whose installation is required before use.
+#'   `saveHDF5MultiAssayExpeirment` preserves the classes contained in the
+#'   \linkS4class{ExperimentList} with the exception of `matrix` which is
+#'   converted to `HDF5Matrix`. Internal `SummarizedExperiment` assays are
+#'   converted to HDF5-backed assays as in
+#'   `HDF5Array::saveHDF5SummarizedExperiment`. `SummarizedExperiment`
+#'   objects with multiple `i`-th assays will have the first assay take
+#'   precedence and others assays will be dropped with a warning.
+#'   If the first assay in a `SummarizedExperiment` contains an array,
+#'   the array is preserved in the process of saving and loading the
+#'   HDF5-backed `MultiAssayExperiment`.
 #'
 #' @inheritParams HDF5Array::saveHDF5SummarizedExperiment
 #'
 #' @param x A \linkS4class{MultiAssayExperiment} object or derivative
 #'
 #' @param dir The path (as a single string) to the directory where to save the
-#'     HDF5-based \linkS4class{MultiAssayExperiment} object or to load it from.
+#'   HDF5-based \linkS4class{MultiAssayExperiment} object or to load it from.
 #'
-#'     When saving, the directory will be created if it doesn't already exist.
-#'     If the directory already exists and no prefix is specified and
-#'     `replace` is set to `TRUE`, then it's replaced with an
-#'     empty directory.
+#'   When saving, the directory will be created if it doesn't already exist.
+#'   If the directory already exists and no prefix is specified and
+#'   `replace` is set to `TRUE`, then it's replaced with an
+#'   empty directory.
 #'
 #' @param prefix An optional prefix to add to the names of the files created
-#'     inside `dir`. Allows saving more than one object in the same
-#'     directory. When the prefix is `NULL`, the name of the
-#'     `MultiAssayExperiment` object is used. To avoid the default setting
-#'     use an empty character string i.e., `""`.
+#'   inside `dir`. This allows saving more than one object in the same
+#'   directory. When the prefix is `NULL`, the name of the `x` input
+#'   `MultiAssayExperiment` is used. To avoid the default setting
+#'   use an empty character string i.e., `""`. An underscore (`_`) is
+#'   appended to the prefix when provided; therefore, typical inputs should be
+#'   words, e.g., "test".
 #'
 #' @param verbose Set to `TRUE` to make the function display progress.
 #'
-#'     In the case of `saveHDF5MultiAssayExperiment()`, `verbose`
-#'     is set to `NA` by default, in which case verbosity is controlled
-#'     by `DelayedArray:::get_verbose_block_processing()`. Setting
-#'     `verbose` to `TRUE` or `FALSE` overrides this.
+#'   In the case of `saveHDF5MultiAssayExperiment()`, `verbose`
+#'   is set to `NA` by default, in which case verbosity is controlled
+#'   by `DelayedArray.verbose.block.processing` option. Setting
+#'   `verbose` to `TRUE` or `FALSE` overrides the option.
 #'
 #' @md
 #'
@@ -144,16 +146,19 @@ saveHDF5MultiAssayExperiment <-
     )
 {
     if (is.null(prefix))
-        prefix <- paste0(as.character(substitute(x)), "_")
+        prefix <- as.character(substitute(x))
+
+    if (nzchar(prefix))
+        prefix <- paste0(prefix, "_")
 
     .load_HDF5Array_package()
 
     stopifnot(.isSingleString(dir), .isSingleString(prefix))
 
-    if (!S4Vectors::isTRUEorFALSE(replace))
+    if (!BiocBaseUtils::isTRUEorFALSE(replace))
         stop("'replace' must be TRUE or FALSE")
 
-    verbose <- DelayedArray:::normarg_verbose(verbose)
+    verbose <- .normarg_verbose(verbose)
 
     if (!dir.exists(dir)) {
         HDF5Array::create_dir(dir)
@@ -180,13 +185,13 @@ loadHDF5MultiAssayExperiment <- function(dir = "h5_mae", prefix = NULL)
 {
     .load_HDF5Array_package()
     if (is.null(prefix)) {
-        prefix <- unique(
-            vapply(strsplit(dir(dir), "_"), '[', character(1L), 1L)
-        )
+        pattern <- paste0(.MAE_RDS_BASENAME, "|", .EXPERIMENTS_H5_BASENAME)
+        prefix <- unique(gsub(pattern, "", dir(dir)))
         if (length(prefix) > 1L)
             stop("More than one object saved in 'dir', specify a 'prefix'")
     }
-    prefix <- if (nchar(prefix)) { paste0(prefix, "_") } else { prefix }
+    if (nzchar(prefix) && !endsWith(prefix, "_"))
+        prefix <- paste0(prefix, "_")
 
     stopifnot(.isSingleString(dir), .isSingleString(prefix))
 
@@ -245,7 +250,7 @@ loadHDF5MultiAssayExperiment <- function(dir = "h5_mae", prefix = NULL)
             )
         }
     }
-    ans <- BiocGenerics:::replaceSlots(
+    ans <- BiocBaseUtils::setSlots(
         ans, ExperimentList = explist, check = FALSE
     )
     ans <- updateObject(ans, check=FALSE)
